<?php

namespace Internetgalerie\IgWidgets\Widgets;

use Internetgalerie\IgWidgets\Widgets\Provider\TableProviderInterface;
use TYPO3\CMS\Backend\Routing\UriBuilder;
use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
use TYPO3\CMS\Core\Routing\RouteNotFoundException;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Dashboard\Widgets\AdditionalCssInterface;
use TYPO3\CMS\Dashboard\Widgets\ButtonProviderInterface;
use TYPO3\CMS\Dashboard\Widgets\ListDataProviderInterface;
use TYPO3\CMS\Dashboard\Widgets\WidgetConfigurationInterface;
use TYPO3\CMS\Dashboard\Widgets\WidgetInterface;
use TYPO3\CMS\Fluid\View\StandaloneView;

class TableWidget implements WidgetInterface, AdditionalCssInterface
{
    /**
     * @var WidgetConfigurationInterface
     */
    private $configuration;

    /**
     * @var StandaloneView
     */
    private $view;

    /**
     * @var TableProviderInterface
     */
    private $dataProvider;

    /**
     * @var array
     */
    private $options;

    /**
     * @var ButtonProviderInterface|null
     */
    private $buttonProvider;

    public function __construct(
        WidgetConfigurationInterface $configuration,
        TableProviderInterface $dataProvider,
        StandaloneView $view,
        ButtonProviderInterface $buttonProvider = null,
        array $options = []
    ) {
        $this->configuration = $configuration;
        $this->view = $view;
        $this->dataProvider = $dataProvider;
        $this->options =  array_merge(
            [
                'template' => 'IgWidgets/Widget/TableWidget',
            ],
            $options
        );
        $this->buttonProvider = $buttonProvider;
    }
    public function getCssFiles(): array
    {
        return [
            'EXT:ig_widgets/Resources/Public/Css/tableWidget.css',
        ];
    }

    public function renderWidgetContent(): string
    {
        $this->view->setTemplate($this->options['template']);
        $this->dataProvider->setOptions($this->options);

        $pageUid = $this->dataProvider->getPageUid();
        $pageUid = $this->dataProvider->getPageUid();
        //$url='/typo3/index.php?route=%2Fmodule%2Fweb%2FIndexedSearchIsearch';
        $uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
        if ($this->options['routeName']) {
            try {
                $url = (string)$uriBuilder->buildUriFromRoute($this->options['routeName'], ['id' => $pageUid]);
                $detailAction = 'top.jump(' . GeneralUtility::quoteJSvalue($url) . ',' . GeneralUtility::quoteJSvalue($this->options['routeName']) . ',' . GeneralUtility::quoteJSvalue('web') . ', ' . (int)$pageUid . ');';
            } catch(RouteNotFoundException $e) {
                $detailAction = null;
                return '';
            }
        } else {
            $detailAction = null;
        }
        //$url = (string)$uriBuilder->buildUriFromRoute('module/web/list', []);
        //$url = (string)$uriBuilder->buildUriFromRoute('system_reports', []);

        $this->view->assignMultiple(
            [
            'limit' => $this->dataProvider->getLimit(),
            'entries' => $this->dataProvider->getEntries(),
            'footer' => $this->dataProvider->getFooter(),
            'options' => $this->options,
            'detailAction' => $detailAction,
            'days' => $this->dataProvider->getDays(),
            'button' => $this->buttonProvider,
            'configuration' => $this->configuration,
             'dateFormat' => $GLOBALS['TYPO3_CONF_VARS']['SYS']['ddmmyy'],
            'timeFormat' => $GLOBALS['TYPO3_CONF_VARS']['SYS']['hhmm'],
            ]
        );
        return $this->view->render();
    }

    /**
     * This method returns the options of the widget as set in the registration.
     */
    public function getOptions(): array
    {
        return $this->options;
    }
}